aboutsummaryrefslogtreecommitdiffstats
path: root/lib/private/Config.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/private/Config.php')
-rw-r--r--lib/private/Config.php82
1 files changed, 30 insertions, 52 deletions
diff --git a/lib/private/Config.php b/lib/private/Config.php
index 3ea822101df..ee30b8efc5e 100644
--- a/lib/private/Config.php
+++ b/lib/private/Config.php
@@ -1,40 +1,9 @@
<?php
+
/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Adam Williamson <awilliam@redhat.com>
- * @author Aldo "xoen" Giambelluca <xoen@xoen.org>
- * @author Bart Visscher <bartv@thisnet.nl>
- * @author Brice Maron <brice@bmaron.net>
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Daniel Kesselberg <mail@danielkesselberg.de>
- * @author Frank Karlitschek <frank@karlitschek.de>
- * @author Jakob Sack <mail@jakobsack.de>
- * @author Jan-Christoph Borchardt <hey@jancborchardt.net>
- * @author Joas Schilling <coding@schilljs.com>
- * @author John Molakvoæ <skjnldsv@protonmail.com>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Michael Gapczynski <GapczynskiM@gmail.com>
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Philipp Schaffrath <github@philipp.schaffrath.email>
- * @author Robin Appelman <robin@icewind.nl>
- * @author Robin McCorkell <robin@mccorkell.me.uk>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program. If not, see <http://www.gnu.org/licenses/>
- *
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
*/
namespace OC;
@@ -153,8 +122,6 @@ class Config {
* @throws HintException
*/
protected function set($key, $value) {
- $this->checkReadOnly();
-
if (!isset($this->cache[$key]) || $this->cache[$key] !== $value) {
// Add change
$this->cache[$key] = $value;
@@ -185,8 +152,6 @@ class Config {
* @throws HintException
*/
protected function delete($key) {
- $this->checkReadOnly();
-
if (isset($this->cache[$key])) {
// Delete key from cache
unset($this->cache[$key]);
@@ -215,13 +180,24 @@ class Config {
// Include file and merge config
foreach ($configFiles as $file) {
- $fileExistsAndIsReadable = file_exists($file) && is_readable($file);
- $filePointer = $fileExistsAndIsReadable ? fopen($file, 'r') : false;
- if ($file === $this->configFilePath &&
- $filePointer === false) {
- // Opening the main config might not be possible, e.g. if the wrong
- // permissions are set (likely on a new installation)
- continue;
+ unset($CONFIG);
+
+ // Invalidate opcache (only if the timestamp changed)
+ if (function_exists('opcache_invalidate')) {
+ opcache_invalidate($file, false);
+ }
+
+ $filePointer = @fopen($file, 'r');
+ if ($filePointer === false) {
+ // e.g. wrong permissions are set
+ if ($file === $this->configFilePath) {
+ // opening the main config file might not be possible
+ // (likely on a new installation)
+ continue;
+ }
+
+ http_response_code(500);
+ die(sprintf('FATAL: Could not open the config file %s', $file));
}
// Try to acquire a file lock
@@ -229,8 +205,14 @@ class Config {
throw new \Exception(sprintf('Could not acquire a shared lock on the config file %s', $file));
}
- unset($CONFIG);
- include $file;
+ try {
+ include $file;
+ } finally {
+ // Close the file pointer and release the lock
+ flock($filePointer, LOCK_UN);
+ fclose($filePointer);
+ }
+
if (!defined('PHPUNIT_RUN') && headers_sent()) {
// syntax issues in the config file like leading spaces causing PHP to send output
$errorMessage = sprintf('Config file has leading content, please remove everything before "<?php" in %s', basename($file));
@@ -242,10 +224,6 @@ class Config {
if (isset($CONFIG) && is_array($CONFIG)) {
$this->cache = array_merge($this->cache, $CONFIG);
}
-
- // Close the file pointer and release the lock
- flock($filePointer, LOCK_UN);
- fclose($filePointer);
}
$this->envCache = getenv();